Hedgehog Client Library
=======================

Master: |travis-master|_ |coveralls-master|_

Develop: |travis-develop|_ |coveralls-develop|_

.. |travis-master| image:: https://travis-ci.org/PRIArobotics/HedgehogClient.svg?branch=master
.. _travis-master: https://travis-ci.org/PRIArobotics/HedgehogClient
.. |coveralls-master| image:: https://coveralls.io/repos/github/PRIArobotics/HedgehogClient/badge.svg?branch=master
.. _coveralls-master: https://coveralls.io/github/PRIArobotics/HedgehogClient?branch=master
.. |travis-develop| image:: https://travis-ci.org/PRIArobotics/HedgehogClient.svg?branch=develop
.. _travis-develop: https://travis-ci.org/PRIArobotics/HedgehogClient
.. |coveralls-develop| image:: https://coveralls.io/repos/github/PRIArobotics/HedgehogClient/badge.svg?branch=develop
.. _coveralls-develop: https://coveralls.io/github/PRIArobotics/HedgehogClient?branch=develop

----

This project provides a client library to communicate with Hedgehog Educational Robotics Controllers.
